==> odata-client-microsoft-dynamics-0.1.38-sources.jar: microsoft/dynamics/crm/entity/collection/request/Msdyn_slakpiCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.internal.RequestHelper;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Msdyn_slakpi;
import microsoft.dynamics.crm.entity.request.AsyncoperationRequest;
import microsoft.dynamics.crm.entity.request.BulkdeletefailureRequest;
import microsoft.dynamics.crm.entity.request.DuplicaterecordRequest;
import microsoft.dynamics.crm.entity.request.MailboxtrackingfolderRequest;
import microsoft.dynamics.crm.entity.request.Msdyn_slakpiRequest;
import microsoft.dynamics.crm.entity.request.PrincipalobjectattributeaccessRequest;
import microsoft.dynamics.crm.entity.request.ProcesssessionRequest;
import microsoft.dynamics.crm.entity.request.SlaitemRequest;
import microsoft.dynamics.crm.entity.request.SyncerrorRequest;
import microsoft.dynamics.crm.schema.SchemaInfo;

public class Msdyn_slakpiCollectionRequest extends CollectionPageEntityRequest<Msdyn_slakpi, Msdyn_slakpiRequest>{

    protected ContextPath contextPath;

    public Msdyn_slakpiCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Msdyn_slakpi.class, cp -> new Msdyn_slakpiRequest(cp, Optional.empty()), SchemaInfo.INSTANCE, value);
        this.contextPath = contextPath;
    }

    public SyncerrorCollectionRequest msdyn_slakpi_SyncErrors() {
        return new SyncerrorCollectionRequest(contextPath.addSegment("msdyn_slakpi_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest msdyn_slakpi_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("msdyn_slakpi_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest msdyn_slakpi_DuplicateMatchingRecord() {
        return new DuplicaterecordCollectionRequest(contextPath.addSegment("msdyn_slakpi_DuplicateMatchingRecord"), Optional.empty());
    }

    public DuplicaterecordRequest msdyn_slakpi_DuplicateMatchingRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("msdyn_slakpi_DuplicateMatchingRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest msdyn_slakpi_DuplicateBaseRecord() {
        return new DuplicaterecordCollectionRequest(contextPath.addSegment("msdyn_slakpi_DuplicateBaseRecord"), Optional.empty());
    }

    public DuplicaterecordRequest msdyn_slakpi_DuplicateBaseRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("msdyn_slakpi_DuplicateBaseRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public AsyncoperationCollectionRequest msdyn_slakpi_AsyncOperations() {
        return new AsyncoperationCollectionRequest(contextPath.addSegment("msdyn_slakpi_AsyncOperations"), Optional.empty());
    }

    public AsyncoperationRequest msdyn_slakpi_AsyncOperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("msdyn_slakpi_AsyncOperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

    public MailboxtrackingfolderCollectionRequest msdyn_slakpi_MailboxTrackingFolders() {
        return new MailboxtrackingfolderCollectionRequest(contextPath.addSegment("msdyn_slakpi_MailboxTrackingFolders"), Optional.empty());
    }

    public MailboxtrackingfolderRequest msdyn_slakpi_MailboxTrackingFolders(String mailboxtrackingfolderid) {
        return new MailboxtrackingfolderRequest(contextPath.addSegment("msdyn_slakpi_MailboxTrackingFolders").addKeys(new NameValue(mailboxtrackingfolderid.toString())), Optional.empty());
    }

    public ProcesssessionCollectionRequest msdyn_slakpi_ProcessSession() {
        return new ProcesssessionCollectionRequest(contextPath.addSegment("msdyn_slakpi_ProcessSession"), Optional.empty());
    }

    public ProcesssessionRequest msdyn_slakpi_ProcessSession(String processsessionid) {
        return new ProcesssessionRequest(contextPath.addSegment("msdyn_slakpi_ProcessSession").addKeys(new NameValue(processsessionid.toString())), Optional.empty());
    }

    public BulkdeletefailureCollectionRequest msdyn_slakpi_BulkDeleteFailures() {
        return new BulkdeletefailureCollectionRequest(contextPath.addSegment("msdyn_slakpi_BulkDeleteFailures"), Optional.empty());
    }

    public BulkdeletefailureRequest msdyn_slakpi_BulkDeleteFailures(String bulkdeletefailureid) {
        return new BulkdeletefailureRequest(contextPath.addSegment("msdyn_slakpi_BulkDeleteFailures").addKeys(new NameValue(bulkdeletefailureid.toString())), Optional.empty());
    }

    public PrincipalobjectattributeaccessCollectionRequest msdyn_slakpi_PrincipalObjectAttributeAccesses() {
        return new PrincipalobjectattributeaccessCollectionRequest(contextPath.addSegment("msdyn_slakpi_PrincipalObjectAttributeAccesses"), Optional.empty());
    }

    public PrincipalobjectattributeaccessRequest msdyn_slakpi_PrincipalObjectAttributeAccesses(String principalobjectattributeaccessid) {
        return new PrincipalobjectattributeaccessRequest(contextPath.addSegment("msdyn_slakpi_PrincipalObjectAttributeAccesses").addKeys(new NameValue(principalobjectattributeaccessid.toString())), Optional.empty());
    }

    public SlaitemCollectionRequest msdyn_msdyn_slakpi_slaitem() {
        return new SlaitemCollectionRequest(contextPath.addSegment("msdyn_msdyn_slakpi_slaitem"), Optional.empty());
    }

    public SlaitemRequest msdyn_msdyn_slakpi_slaitem(String slaitemid) {
        return new SlaitemRequest(contextPath.addSegment("msdyn_msdyn_slakpi_slaitem").addKeys(new NameValue(slaitemid.toString())), Optional.empty());
    }

}

==> odata-client-microsoft-dynamics-0.1.39-sources.jar: microsoft/dynamics/crm/entity/collection/request/Msdyn_slakpiCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.internal.RequestHelper;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Msdyn_slakpi;
import microsoft.dynamics.crm.entity.request.AsyncoperationRequest;
import microsoft.dynamics.crm.entity.request.BulkdeletefailureRequest;
import microsoft.dynamics.crm.entity.request.DuplicaterecordRequest;
import microsoft.dynamics.crm.entity.request.MailboxtrackingfolderRequest;
import microsoft.dynamics.crm.entity.request.Msdyn_slakpiRequest;
import microsoft.dynamics.crm.entity.request.PrincipalobjectattributeaccessRequest;
import microsoft.dynamics.crm.entity.request.ProcesssessionRequest;
import microsoft.dynamics.crm.entity.request.SlaitemRequest;
import microsoft.dynamics.crm.entity.request.SyncerrorRequest;

public class Msdyn_slakpiCollectionRequest extends CollectionPageEntityRequest<Msdyn_slakpi, Msdyn_slakpiRequest>{

    protected ContextPath contextPath;

    public Msdyn_slakpiCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Msdyn_slakpi.class, cp -> new Msdyn_slakpiRequest(cp, Optional.empty()), value);
        this.contextPath = contextPath;
    }

    public SyncerrorCollectionRequest msdyn_slakpi_SyncErrors() {
        return new SyncerrorCollectionRequest(contextPath.addSegment("msdyn_slakpi_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest msdyn_slakpi_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("msdyn_slakpi_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest msdyn_slakpi_DuplicateMatchingRecord() {
        return new DuplicaterecordCollectionRequest(contextPath.addSegment("msdyn_slakpi_DuplicateMatchingRecord"), Optional.empty());
    }

    public DuplicaterecordRequest msdyn_slakpi_DuplicateMatchingRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("msdyn_slakpi_DuplicateMatchingRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest msdyn_slakpi_DuplicateBaseRecord() {
        return new DuplicaterecordCollectionRequest(contextPath.addSegment("msdyn_slakpi_DuplicateBaseRecord"), Optional.empty());
    }

    public DuplicaterecordRequest msdyn_slakpi_DuplicateBaseRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("msdyn_slakpi_DuplicateBaseRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public AsyncoperationCollectionRequest msdyn_slakpi_AsyncOperations() {
        return new AsyncoperationCollectionRequest(contextPath.addSegment("msdyn_slakpi_AsyncOperations"), Optional.empty());
    }

    public AsyncoperationRequest msdyn_slakpi_AsyncOperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("msdyn_slakpi_AsyncOperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

    public MailboxtrackingfolderCollectionRequest msdyn_slakpi_MailboxTrackingFolders() {
        return new MailboxtrackingfolderCollectionRequest(contextPath.addSegment("msdyn_slakpi_MailboxTrackingFolders"), Optional.empty());
    }

    public MailboxtrackingfolderRequest msdyn_slakpi_MailboxTrackingFolders(String mailboxtrackingfolderid) {
        return new MailboxtrackingfolderRequest(contextPath.addSegment("msdyn_slakpi_MailboxTrackingFolders").addKeys(new NameValue(mailboxtrackingfolderid.toString())), Optional.empty());
    }

    public ProcesssessionCollectionRequest msdyn_slakpi_ProcessSession() {
        return new ProcesssessionCollectionRequest(contextPath.addSegment("msdyn_slakpi_ProcessSession"), Optional.empty());
    }

    public ProcesssessionRequest msdyn_slakpi_ProcessSession(String processsessionid) {
        return new ProcesssessionRequest(contextPath.addSegment("msdyn_slakpi_ProcessSession").addKeys(new NameValue(processsessionid.toString())), Optional.empty());
    }

    public BulkdeletefailureCollectionRequest msdyn_slakpi_BulkDeleteFailures() {
        return new BulkdeletefailureCollectionRequest(contextPath.addSegment("msdyn_slakpi_BulkDeleteFailures"), Optional.empty());
    }

    public BulkdeletefailureRequest msdyn_slakpi_BulkDeleteFailures(String bulkdeletefailureid) {
        return new BulkdeletefailureRequest(contextPath.addSegment("msdyn_slakpi_BulkDeleteFailures").addKeys(new NameValue(bulkdeletefailureid.toString())), Optional.empty());
    }

    public PrincipalobjectattributeaccessCollectionRequest msdyn_slakpi_PrincipalObjectAttributeAccesses() {
        return new PrincipalobjectattributeaccessCollectionRequest(contextPath.addSegment("msdyn_slakpi_PrincipalObjectAttributeAccesses"), Optional.empty());
    }

    public PrincipalobjectattributeaccessRequest msdyn_slakpi_PrincipalObjectAttributeAccesses(String principalobjectattributeaccessid) {
        return new PrincipalobjectattributeaccessRequest(contextPath.addSegment("msdyn_slakpi_PrincipalObjectAttributeAccesses").addKeys(new NameValue(principalobjectattributeaccessid.toString())), Optional.empty());
    }

    public SlaitemCollectionRequest msdyn_msdyn_slakpi_slaitem() {
        return new SlaitemCollectionRequest(contextPath.addSegment("msdyn_msdyn_slakpi_slaitem"), Optional.empty());
    }

    public SlaitemRequest msdyn_msdyn_slakpi_slaitem(String slaitemid) {
        return new SlaitemRequest(contextPath.addSegment("msdyn_msdyn_slakpi_slaitem").addKeys(new NameValue(slaitemid.toString())), Optional.empty());
    }

}
